Simplify
********

.. currentmodule:: diofant.simplify.simplify

simplify
--------
.. autofunction:: simplify

separatevars
------------
.. autofunction:: separatevars

nthroot
-------
.. autofunction:: nthroot

besselsimp
----------
.. autofunction:: besselsimp

hypersimp
---------
.. autofunction:: hypersimp

hypersimilar
------------
.. autofunction:: hypersimilar

nsimplify
---------
.. autofunction:: nsimplify

posify
------
.. autofunction:: posify

logcombine
----------
.. autofunction:: logcombine

Radsimp
-------
.. module:: diofant.simplify.radsimp

radsimp
^^^^^^^
.. autofunction:: radsimp

rad_rationalize
^^^^^^^^^^^^^^^
.. autofunction:: rad_rationalize

collect
^^^^^^^
.. autofunction:: collect

.. autofunction:: rcollect

collect_sqrt
^^^^^^^^^^^^
.. autofunction:: collect_sqrt

collect_const
^^^^^^^^^^^^^
.. autofunction:: collect_const

fraction
^^^^^^^^
.. autofunction:: fraction

Ratsimp
-------
.. module:: diofant.simplify.ratsimp

ratsimp
^^^^^^^
.. autofunction:: ratsimp

Trigonometric simplification
----------------------------
.. module:: diofant.simplify.trigsimp

trigsimp
^^^^^^^^
.. autofunction:: trigsimp

futrig
^^^^^^
.. autofunction:: futrig

fu
^^
.. module:: diofant.simplify.fu
.. autofunction:: fu

Power simplification
--------------------
.. module:: diofant.simplify.powsimp

powsimp
^^^^^^^
.. autofunction:: powsimp

powdenest
^^^^^^^^^
.. autofunction:: powdenest

Combinatorial simplification
----------------------------
.. module:: diofant.simplify.combsimp

combsimp
^^^^^^^^
.. autofunction:: combsimp

Square Root Denest
------------------
.. module:: diofant.simplify.sqrtdenest

sqrtdenest
^^^^^^^^^^
.. autofunction:: sqrtdenest

unrad
^^^^^
.. autofunction:: unrad

Common Subexpresion Elimination
-------------------------------
.. module:: diofant.simplify.cse_main

cse
^^^
.. autofunction:: cse

opt_cse
^^^^^^^
.. autofunction:: diofant.simplify.cse_main.opt_cse

tree_cse
^^^^^^^^
.. autofunction:: diofant.simplify.cse_main.tree_cse

Hypergeometric Function Expansion
---------------------------------
.. module:: diofant.simplify.hyperexpand

hyperexpand
^^^^^^^^^^^
.. autofunction:: hyperexpand

Traversal Tools
---------------
.. module:: diofant.simplify.traversaltools

use
^^^
.. autofunction:: use

EPath Tools
-----------
.. module:: diofant.simplify.epathtools

EPath class
^^^^^^^^^^^
.. autoclass:: EPath
   :members:

epath
^^^^^
.. autofunction:: epath
